@@ -1,14 +1,16 @@
-# Copyright (C) 2013 Julian Metzler
 # See the LICENSE file for the full license.
 
 class APIError(Exception):
-	def __init__(self, code, description, body = None):
+	def __init__(self, description, code = None, body = None):
 		self.code = code
 		self.description = description
 		self.body = body
 	
 	def __str__(self):
-		return "#%i: %s" % (self.code, self.description)
+		if self.code is None:
+			return self.description
+		else:
+			return "%i: %s" % (self.code, self.description)
 
 class ParameterError(Exception):
 	def __init__(self, description):
